pub enum CodecErrorKind {
UnexpectedEof,
InvalidValue,
LengthOverflow,
TrailingBytes,
WriteFailed,
ReadFailed,
}Expand description
High-level category for a codec error.
Variants
UnexpectedEof
The input ended before the requested bytes could be read.
InvalidValue
A value used a byte or tag that is not valid for its type.
LengthOverflow
A decoded length cannot be represented or safely processed.
TrailingBytes
A decoded value left trailing bytes in an exact decode operation.
WriteFailed
The writer failed to accept bytes.
ReadFailed
The reader failed for a reason other than end of input.