Module helpers

Module helpers 

Convenience helpers. Convenience helpers for common encode and decode operations.

Functions

decode_from_slice
Decodes a value from a byte slice and returns the value plus unread byte count.
decode_from_slice_exact
Decodes a value from a byte slice and rejects trailing bytes.
encode_to_vec
Encodes a value into an owned byte vector.